@@ -47,6 +47,7 @@ my %hierarchy = (
     'FontScheme' => 'ResourceBase',
     'FormatScheme' => 'ResourceBase',
     'GradientFill' => 'FillFormat',
+    'HeaderFooter' => 'ResourceBase',
     'HtmlExportOptions' => 'ExportOptions',
     'Image' => 'ResourceBase',
     'ImageExportOptions' => 'ExportOptions',
@@ -58,6 +59,7 @@ my %hierarchy = (
     'Merge' => 'Task',
     'NoFill' => 'FillFormat',
     'NotesSlide' => 'ResourceBase',
+    'NotesSlideHeaderFooter' => 'ResourceBase',
     'OneValueChartDataPoint' => 'DataPoint',
     'OneValueSeries' => 'Series',
     'Paragraph' => 'ResourceBase',
@@ -84,6 +86,8 @@ my %hierarchy = (
     'SaveSlide' => 'Task',
     'ScatterChartDataPoint' => 'DataPoint',
     'ScatterSeries' => 'Series',
+    'Section' => 'ResourceBase',
+    'Sections' => 'ResourceBase',
     'ShapeBase' => 'ResourceBase',
     'Shapes' => 'ResourceBase',
     'Slide' => 'ResourceBase',
@@ -208,6 +212,7 @@ my %determiners = (
     'FontScheme' => {  },
     'FormatScheme' => {  },
     'GradientFill' => { 'Type' => 'Gradient', },
+    'HeaderFooter' => {  },
     'HtmlExportOptions' => { 'Format' => 'html', },
     'Image' => {  },
     'ImageExportOptions' => { 'Format' => 'image', },
@@ -219,6 +224,7 @@ my %determiners = (
     'Merge' => { 'Type' => 'Merge', },
     'NoFill' => { 'Type' => 'NoFill', },
     'NotesSlide' => {  },
+    'NotesSlideHeaderFooter' => {  },
     'OneValueChartDataPoint' => {  },
     'OneValueSeries' => { 'DataPointType' => 'OneValue', },
     'Paragraph' => {  },
@@ -245,6 +251,8 @@ my %determiners = (
     'SaveSlide' => { 'Type' => 'SaveSlide', },
     'ScatterChartDataPoint' => {  },
     'ScatterSeries' => { 'DataPointType' => 'Scatter', },
+    'Section' => {  },
+    'Sections' => {  },
     'ShapeBase' => {  },
     'Shapes' => {  },
     'Slide' => {  },
